@@ -57,8 +57,8 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <locale.h>
 #ifdef HAS_OPENBABEL_2
-#	include <mol.h>
-#	include <obconversion.h>
+#	include <openbabel/mol.h>
+#	include <openbabel/obconversion.h>
 #else
 #	include <sstream>
 #endif
@@ -295,7 +295,7 @@ void gcpApplication::SetStatusText(const char* text)
 
 void gcpApplication::OnSaveAs()
 {
-	gcpFileChooser* fc = new gcpFileChooser (this, true, m_pActiveDoc);
+	new gcpFileChooser (this, true, m_pActiveDoc);
 }
 
 void gcpApplication::AddUI (const char* filename)
@@ -307,7 +307,10 @@ void gcpApplication::AddUI (const char* filename)
 	else 
 	{
 		BonoboUINode *Child, *Next;
-		if (!strcmp(bonobo_ui_node_get_name(Parent), "Root")) Node = bonobo_ui_node_children (Parent);
+		if (!strcmp(bonobo_ui_node_get_name (Parent), "Root"))
+			Node = bonobo_ui_node_children (Parent);
+		else
+			Node = NULL;
 		while (Node)
 		{
 			const char* name = bonobo_ui_node_get_name (Node);
@@ -397,7 +400,6 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 				break;
 		}
 	gchar* filename2;
-	struct stat buf;
 	bool err;
 	GnomeVFSURI *uri;
 	if (bSave)
@@ -426,6 +428,8 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 		}
 		if (result == GTK_RESPONSE_YES)
 		{
+			// destroy the old file
+			gnome_vfs_unlink (filename2);
 #ifdef HAS_OPENBABEL_2
 			pDoc->SetType (filetype);
 			if (filetype == gcp_ft_Normal)
@@ -613,7 +617,7 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 	}
 	catch (int num)
 	{
-		gchar *mess;
+		gchar *mess = NULL;
 		GtkWidget* message;
 		switch (num)
 		{
@@ -626,6 +630,8 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 		case 2:
 			mess = g_strdup_printf(_("%s: parse error."), filename);
 			break;
+		default:
+			throw (num); //this should not occur
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
 		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
@@ -649,7 +655,7 @@ static int	cb_vfs_to_xml (GnomeVFSHandle *handle, char* buf, int nb)
 
 void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 {
-	xmlDocPtr xml;
+	xmlDocPtr xml = NULL;
 	char *old_num_locale, *old_time_locale;
 	GnomeVFSFileInfo *info = NULL;
 	try
@@ -703,7 +709,7 @@ void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 		if (info)
 			gnome_vfs_file_info_unref (info);
 		if (num > 1) xmlFreeDoc(xml);
-		gchar *mess;
+		gchar *mess = NULL;
 		GtkWidget* message;
 		switch (num)
 		{
@@ -722,6 +728,8 @@ void gcpApplication::OpenGcp(const gchar* filename, gcpDocument* pDoc)
 		case 4:
 			mess = g_strdup_printf(_("%s: parse error."), filename);
 			break;
+		default:
+			throw (num); //this should not occur
 		}
 		message = gtk_message_dialog_new(NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess);
 		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
