@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2002-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -31,14 +31,12 @@
 
 using namespace gcu;
 
-typedef enum
+enum
 {
 	gcpSimpleArrow,
 	gcpReversibleArrow,
-	NotAnArrow1,
-	NotAnArrow2,
-	gcpDoubleHeadedArrow
-} gcpArrowType;
+	gcpFullReversibleArrow,
+};
 
 class gcpArrow: public Object
 {
@@ -52,6 +50,7 @@ public:
 	bool GetCoords(double* xstart, double* ystart, double* xend, double* yend);
 	virtual void Move(double x, double y, double z = 0);
 	virtual void Transform2D(Matrix2D& m, double x, double y);
+	virtual double GetYAlign ();
 
 protected:
 	bool Save(xmlDocPtr xml, xmlNodePtr node);
