@@ -105,6 +105,13 @@ bool gcpFragment::OnChanged(GtkTextBuffer *textbuffer)
 		gnome_canvas_rich_text_ext_get_iter_location(text, &iter, &rect);
 		m_height = rect.height + 1;
 		m_length = 1;
+		GtkTextMark *mark = gtk_text_buffer_get_mark (m_buf, "insert");
+		gtk_text_buffer_get_iter_at_mark(m_buf, &start, mark);
+		gtk_text_buffer_delete_mark (m_buf, m_BeginAtom);
+		m_BeginAtom = gtk_text_buffer_create_mark (m_buf, "ab0", &start, true);
+		gtk_text_buffer_delete_mark (m_buf, m_EndAtom);
+		m_EndAtom = gtk_text_buffer_create_mark (m_buf, "ae0", &start, false);
+		m_lbearing = 0;
 		pView->Update (this);
 		EmitSignal (OnChangedSignal);
 		m_bLoading = false;
@@ -149,24 +156,34 @@ bool gcpFragment::OnChanged(GtkTextBuffer *textbuffer)
 		//atom has been partly deleted at least
 			Z = GetElementAtIter(&start, &iter);
 			m_Atom->SetZ(Z);
-			if (!Z)
-			{
-				gtk_text_buffer_delete_mark(m_buf, m_BeginAtom);
-				m_BeginAtom = gtk_text_buffer_create_mark(m_buf, "ab0", &start, true);
+			if (!Z) {
+				GtkTextMark *mark = gtk_text_buffer_get_mark (m_buf, "insert");
+				gtk_text_buffer_get_iter_at_mark(m_buf, &start, mark);
+				gtk_text_buffer_delete_mark (m_buf, m_BeginAtom);
+				m_BeginAtom = gtk_text_buffer_create_mark (m_buf, "ab0", &start, false);
+				gtk_text_buffer_delete_mark (m_buf, m_EndAtom);
+				m_EndAtom = gtk_text_buffer_create_mark (m_buf, "ae0", &start, true);
+			} else {
+				gtk_text_buffer_delete_mark(m_buf, m_EndAtom);
+				m_EndAtom = gtk_text_buffer_create_mark(m_buf, "ae0", &iter, true);
 			}
-			gtk_text_buffer_delete_mark(m_buf, m_EndAtom);
-			m_EndAtom = gtk_text_buffer_create_mark(m_buf, "ae0", &iter, true);
 		}
 		else if (strlen(symbol) < 3)
 		{
-			Z = GetElementAtIter(&start, &iter);
-			if (Z)
-			{
-				m_Atom->SetZ(Z);
-				gtk_text_buffer_delete_mark(m_buf, m_BeginAtom);
-				m_BeginAtom = gtk_text_buffer_create_mark(m_buf, "ab0", &start, false);
-				gtk_text_buffer_delete_mark(m_buf, m_EndAtom);
-				m_EndAtom = gtk_text_buffer_create_mark(m_buf, "ae0", &iter, true);
+			Z = GetElementAtIter (&start, &iter);
+			if (Z) {
+				m_Atom->SetZ (Z);
+				gtk_text_buffer_delete_mark (m_buf, m_BeginAtom);
+				m_BeginAtom = gtk_text_buffer_create_mark (m_buf, "ab0", &start, false);
+				gtk_text_buffer_delete_mark (m_buf, m_EndAtom);
+				m_EndAtom = gtk_text_buffer_create_mark (m_buf, "ae0", &iter, true);
+			} else {
+				GtkTextMark *mark = gtk_text_buffer_get_mark (m_buf, "insert");
+				gtk_text_buffer_get_iter_at_mark(m_buf, &start, mark);
+				gtk_text_buffer_delete_mark (m_buf, m_BeginAtom);
+				m_BeginAtom = gtk_text_buffer_create_mark (m_buf, "ab0", &start, false);
+				gtk_text_buffer_delete_mark (m_buf, m_EndAtom);
+				m_EndAtom = gtk_text_buffer_create_mark (m_buf, "ae0", &start, true);
 			}
 		}
 	}
@@ -246,7 +263,6 @@ bool gcpFragment::OnEndUserAction(GtkTextBuffer *textbuffer)
 	if (m_InsertOffset < 0) return true;
 	if (m_buf != textbuffer) return false;
 	GtkTextIter start, end;
-	char c;
 	gcpDocument* pDoc = (gcpDocument*)GetDocument();
 	gcpApplication* pApp = pDoc->GetApplication();
 	gcpTool* FragmentTool = pApp->GetTool("Fragment");
@@ -441,13 +457,14 @@ void gcpFragment::SetSelected(GtkWidget* w, int state)
 		case SelStateSelected: chargecolor = color = SelectColor; break;
 		case SelStateUpdating: chargecolor = color = AddColor; break;
 		case SelStateErasing: chargecolor = color = DeleteColor; break;
+		default: color = "white"; chargecolor = "black"; break;
 	}
 	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "rect")),
 				"fill_color", color, NULL);
 	gpointer item;
-	if (item = g_object_get_data(G_OBJECT(group), "circle"))
+	if ((item = g_object_get_data(G_OBJECT(group), "circle")))
 		g_object_set (item, "outline_color", chargecolor, NULL);
-	if (item = g_object_get_data(G_OBJECT(group), "sign"))
+	if ((item = g_object_get_data(G_OBJECT(group), "sign")))
 		g_object_set (item, "outline_color", chargecolor, NULL);
 }
 
@@ -654,7 +671,6 @@ bool gcpFragment::SavePortion(xmlDocPtr xml, xmlNodePtr node, GtkTextIter& start
 	int charge;
 	GtkTextTag* tag = gtk_text_tag_table_lookup(TextTagTable, "superscript");
 	cur = start;
-	bool result;
 	while (!gtk_text_iter_equal(&cur, &end))
 	{
 		if (!gtk_text_iter_forward_to_tag_toggle(&cur, tag) || (gtk_text_iter_compare(&cur, &end) > 0))
@@ -710,7 +726,6 @@ xmlNodePtr gcpFragment::SaveSelection(xmlDocPtr xml)
 	int charge;
 	GtkTextTag* tag = gtk_text_tag_table_lookup(TextTagTable, "superscript");
 	cur = start;
-	bool result;
 	while (!gtk_text_iter_equal(&cur, &end))
 	{
 		if (!gtk_text_iter_forward_to_tag_toggle(&cur, tag) || (gtk_text_iter_compare(&cur, &end) > 0))
@@ -949,7 +964,7 @@ void gcpFragment::AnalContent(GtkTextIter& start, GtkTextIter& end)
 						buf = g_strdup_printf("%d%c", abs(charge),(charge > 0)? '+': '-');
 					else if (charge == 1) buf = g_strdup_printf("+");
 					else if (charge == -1) buf = g_strdup_printf("-");
-					else buf = g_strdup_printf("");
+					else buf = g_strdup("");
 					length -= strlen(buf);
 					gtk_text_buffer_get_iter_at_offset(m_buf, &start, pos);
 					gtk_text_buffer_insert_with_tags_by_name(m_buf, &start, buf, -1, "superscript", NULL);
@@ -1081,7 +1096,7 @@ int gcpFragment::GetElementAtIter(GtkTextIter* start, GtkTextIter* end)
 	gtk_text_buffer_get_iter_at_offset(m_buf, end, offset + 3);
 	while (gtk_text_iter_compare(start, end))
 	{
-		if (Z = Element::Z(gtk_text_buffer_get_text(m_buf, start, end, false))) return Z;
+		if ((Z = Element::Z(gtk_text_buffer_get_text(m_buf, start, end, false)))) return Z;
 		gtk_text_iter_backward_char(end);
 	}
 	return 0;
