@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2001-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -28,7 +28,7 @@
 #define GCHEMPAINT_MENDELEIEV_H
 
 #include "dialog.h"
-#include <gtkperiodic/gtkperiodic.h>
+#include <gcu/gtkperiodic.h>
 
 class gcpMendeleievDlg: public gcpDialog
 {
