@@ -47,6 +47,9 @@ extern double DefaultArrowPadding;
 extern double DefaultStoichiometryPadding;
 extern double DefaultObjectPadding;
 extern double DefaultSignPadding;
+extern double ChargeSignHeight;
+extern double ChargeSignSize;
+extern double ChargeYAlign;
 extern gchar *Color, *DeleteColor, *AddColor, *SelectColor;
 extern gchar* DefaultFontFamily;
 extern PangoStyle DefaultFontStyle;
