@@ -4,7 +4,7 @@
  * GChemPaint library
  * text-object.cc 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -118,7 +118,7 @@ bool gcpTextObject::SaveNode(xmlDocPtr xml, xmlNodePtr node)
 bool gcpTextObject::Load (xmlNodePtr node)
 {
 	char* tmp, *endptr;
-	xmlNodePtr child;
+	bool result;
 	tmp = (char*) xmlGetProp (node, (xmlChar*) "id");
 	if (tmp) {
 		SetId (tmp);
@@ -130,15 +130,17 @@ bool gcpTextObject::Load (xmlNodePtr node)
 	if (!tmp)
 		return false;
 	m_x = strtod (tmp, &endptr);
+	result = *endptr;
 	xmlFree (tmp);
-	if (*endptr)
+	if (result)
 		return false;
 	tmp = (char*) xmlGetProp (node, (xmlChar*) "y");
 	if (!tmp)
 		return false;
 	m_y = strtod (tmp, &endptr);
+	result = *endptr;
 	xmlFree (tmp);
-	if (*endptr)
+	if (result)
 		return false;
 	return true;
 }
