@@ -164,33 +164,33 @@ void on_receive(GtkClipboard *clipboard, GtkSelectionData *selection_data, gcpVi
 
 using namespace std;
 
-gcpView::gcpView(gcpDocument *pDoc, bool Embedded)
+gcpView::gcpView (gcpDocument *pDoc, bool Embedded)
 {
 	m_pDoc = pDoc;
-	m_PangoFontDesc = pango_font_description_new();
-	pango_font_description_set_family(m_PangoFontDesc, DefaultFontFamily);
-	pango_font_description_set_style(m_PangoFontDesc, DefaultFontStyle);
-	pango_font_description_set_weight(m_PangoFontDesc, DefaultFontWeight);
-	pango_font_description_set_variant(m_PangoFontDesc, DefaultFontVariant);
-	pango_font_description_set_stretch(m_PangoFontDesc, DefaultFontStretch);
-	pango_font_description_set_size(m_PangoFontDesc, DefaultFontSize);
-	m_sFontName = pango_font_description_to_string(m_PangoFontDesc);
-	m_PangoSmallFontDesc = pango_font_description_new();
-	pango_font_description_set_family(m_PangoSmallFontDesc, DefaultFontFamily);
-	pango_font_description_set_style(m_PangoSmallFontDesc, DefaultFontStyle);
-	pango_font_description_set_weight(m_PangoSmallFontDesc, DefaultFontWeight);
-	pango_font_description_set_variant(m_PangoSmallFontDesc, DefaultFontVariant);
-	pango_font_description_set_stretch(m_PangoSmallFontDesc, DefaultFontStretch);
-	pango_font_description_set_size(m_PangoSmallFontDesc, DefaultFontSize * 2 / 3);
-	m_sSmallFontName = pango_font_description_to_string(m_PangoSmallFontDesc);
-	m_PangoTinyFontDesc = pango_font_description_new();
-	pango_font_description_set_family(m_PangoTinyFontDesc, DefaultFontFamily);
-	pango_font_description_set_style(m_PangoTinyFontDesc, DefaultFontStyle);
-	pango_font_description_set_weight(m_PangoTinyFontDesc, DefaultFontWeight);
-	pango_font_description_set_variant(m_PangoTinyFontDesc, DefaultFontVariant);
-	pango_font_description_set_stretch(m_PangoTinyFontDesc, DefaultFontStretch);
-	pango_font_description_set_size(m_PangoTinyFontDesc, DefaultFontSize / 2);
-	m_sTinyFontName = pango_font_description_to_string(m_PangoTinyFontDesc);
+	m_PangoFontDesc = pango_font_description_new ();
+	pango_font_description_set_family (m_PangoFontDesc, DefaultFontFamily);
+	pango_font_description_set_style (m_PangoFontDesc, DefaultFontStyle);
+	pango_font_description_set_weight (m_PangoFontDesc, DefaultFontWeight);
+	pango_font_description_set_variant (m_PangoFontDesc, DefaultFontVariant);
+	pango_font_description_set_stretch (m_PangoFontDesc, DefaultFontStretch);
+	pango_font_description_set_size (m_PangoFontDesc, DefaultFontSize);
+	m_sFontName = pango_font_description_to_string (m_PangoFontDesc);
+	m_PangoSmallFontDesc = pango_font_description_new ();
+	pango_font_description_set_family (m_PangoSmallFontDesc, DefaultFontFamily);
+	pango_font_description_set_style (m_PangoSmallFontDesc, DefaultFontStyle);
+	pango_font_description_set_weight (m_PangoSmallFontDesc, DefaultFontWeight);
+	pango_font_description_set_variant (m_PangoSmallFontDesc, DefaultFontVariant);
+	pango_font_description_set_stretch (m_PangoSmallFontDesc, DefaultFontStretch);
+	pango_font_description_set_size (m_PangoSmallFontDesc, DefaultFontSize * 2 / 3);
+	m_sSmallFontName = pango_font_description_to_string (m_PangoSmallFontDesc);
+	m_PangoTinyFontDesc = pango_font_description_new ();
+	pango_font_description_set_family (m_PangoTinyFontDesc, DefaultFontFamily);
+	pango_font_description_set_style (m_PangoTinyFontDesc, DefaultFontStyle);
+	pango_font_description_set_weight (m_PangoTinyFontDesc, DefaultFontWeight);
+	pango_font_description_set_variant (m_PangoTinyFontDesc, DefaultFontVariant);
+	pango_font_description_set_stretch (m_PangoTinyFontDesc, DefaultFontStretch);
+	pango_font_description_set_size (m_PangoTinyFontDesc, DefaultFontSize / 2);
+	m_sTinyFontName = pango_font_description_to_string (m_PangoTinyFontDesc);
 	m_DefaultPadding = DefaultPadding;
 	m_DefaultStereoBondWidth = DefaultStereoBondWidth;
 	m_DefaultHashWidth = DefaultHashWidth;
@@ -210,16 +210,22 @@ gcpView::gcpView(gcpDocument *pDoc, bool Embedded)
 	m_width = 400;
 	m_height = 300;
 	m_ActiveRichText = NULL;
-	if (!(m_bEmbedded = Embedded)) CreateNewWidget();
+	if (!(m_bEmbedded = Embedded))
+		CreateNewWidget ();
 	m_UIManager = gtk_ui_manager_new ();
 	m_Dragging = false;
 }
 
-gcpView::~gcpView()
+gcpView::~gcpView ()
 {
-	g_object_unref(G_OBJECT(m_PangoContext));
-	if (m_sFontName) g_free(m_sFontName);
-	if (m_sSmallFontName) g_free(m_sSmallFontName);
+	g_object_unref (G_OBJECT (m_PangoContext));
+	if (m_sFontName)
+		g_free (m_sFontName);
+	if (m_sSmallFontName)
+		g_free (m_sSmallFontName);
+	pango_font_description_free (m_PangoFontDesc);
+	pango_font_description_free (m_PangoSmallFontDesc);
+	pango_font_description_free (m_PangoTinyFontDesc);
 	g_object_unref (m_UIManager);
 }
 
@@ -831,7 +837,7 @@ void gcpView::ExportImage (const char* filename, const char* type)
 	ArtDRect rect;
 	m_pData->GetObjectBounds (m_pDoc, &rect);
 	m_pData->ShowSelection (false);
-	int w = (int) (floor (rect.x1) - ceil (rect.x0)) + 1, h = (int) (floor (rect.y1) - ceil (rect.y0));
+	int w = (int) (ceil (rect.x1) - floor (rect.x0)), h = (int) (ceil (rect.y1) - floor (rect.y0));
 	if (!strcmp (type, "eps")) {
 		GnomePrintConfig* config = gnome_print_config_default();
 		GnomePrintContext *pc;
