@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02111-1307, USA.
  */
 
@@ -33,11 +33,10 @@
 
 #include <libgnomecanvas/gnome-canvas.h>
 #include <libgnomecanvas/gnome-canvas-util.h>
-//#include <libgnomeprint/gnome-print-pango.h>
+#include "gnome-print-pango.h"
 #include "gcp-canvas-rich-text.h"
 #include "gcp-canvas-i18n.h"
 #include "gprintable.h"
-void gnome_print_pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl);
 
 struct _GnomeCanvasRichTextExtPrivate {
 	GtkTextLayout *layout;
@@ -1699,9 +1698,10 @@ gnome_canvas_rich_text_ext_stop_cursor_blink(GnomeCanvasRichTextExt *text)
 static gboolean
 request_update(gpointer data)
 {
+	GnomeCanvasRichTextExt *text;
 	if (!GNOME_IS_CANVAS_RICH_TEXT_EXT (data))
-		return;
-	GnomeCanvasRichTextExt *text = GNOME_CANVAS_RICH_TEXT_EXT(data);
+		return TRUE;
+	text = GNOME_CANVAS_RICH_TEXT_EXT(data);
 
 	gnome_canvas_item_request_update(GNOME_CANVAS_ITEM(text));
 
@@ -2317,7 +2317,7 @@ gnome_canvas_rich_text_ext_add_tag(GnomeCanvasRichTextExt *text, char *tag_name,
 
 PangoLayout* gnome_canvas_rich_text_ext_get_pango_layout (GnomeCanvasRichTextExt *text, gint line)
 {
-	gint top = 0, bottom, firsty;
+	gint top = 0, bottom = 0, firsty;
 	GSList* lines;
 	GtkTextLine* text_line;
 	g_return_val_if_fail (GNOME_IS_CANVAS_RICH_TEXT_EXT (text), NULL);
@@ -2393,8 +2393,6 @@ gnome_canvas_rich_text_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xml
 	GtkTextIter text_iter;
 	GdkRectangle rect;
 	GnomeCanvasRichTextExt *text;
-	xmlNodePtr child;
-	char *buf;
 	g_return_if_fail (GNOME_IS_CANVAS_RICH_TEXT_EXT (printable));
 	text = GNOME_CANVAS_RICH_TEXT_EXT (printable);
 	if (!text->_priv->rendered)
@@ -2422,10 +2420,13 @@ static void
 gnome_canvas_rich_text_ext_ensure_rendered (GnomeCanvasRichTextExt *text)
 {
 	double x1, y1, x2, y2;
-	get_bounds (text, &x1, &y1, &x2, &y2);
-	int w = (int) (ceil (x2) - floor (x1)) + 1, h = (int) (ceil (y2) - floor (y1)) + 1;
-	GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
+	int w, h;
+	GdkPixbuf *pixbuf;
 	GnomeCanvasBuf buf;
+
+	get_bounds (text, &x1, &y1, &x2, &y2);
+	w = (int) (ceil (x2) - floor (x1)) + 1, h = (int) (ceil (y2) - floor (y1)) + 1;
+	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
 	buf.buf = gdk_pixbuf_get_pixels (pixbuf);
 	buf.rect.x0 = (int) floor (x1);
 	buf.rect.x1 = (int) ceil (x2);
