@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,18 +20,24 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
+#ifndef GCHEMPAINT_RETROSYNTHESIS_ARROW_H
+#define GCHEMPAINT_RETROSYNTHESIS_ARROW_H
+
 #include "lib/arrow.h"
 
 extern TypeId RetrosynthesisArrowType;
 
+class gcpRetrosynthesisStep;
+class gcpRetrosynthesis;
+
 class gcpRetrosynthesisArrow: public gcpArrow
 {
 public:
-	gcpRetrosynthesisArrow();
+	gcpRetrosynthesisArrow(gcpRetrosynthesis *rs);
 	virtual ~gcpRetrosynthesisArrow();
 	
 	virtual xmlNodePtr Save(xmlDocPtr xml);
@@ -39,11 +45,14 @@ public:
 	virtual void Add(GtkWidget* w);
 	virtual void Update(GtkWidget* w);
 	virtual void SetSelected(GtkWidget* w, int state);
+	void SetStartStep (gcpRetrosynthesisStep *Step) {m_Start = Step;}
+	gcpRetrosynthesisStep* GetStartStep () {return m_Start;}
+	void SetEndStep (gcpRetrosynthesisStep *Step) {m_End = Step;}
+	gcpRetrosynthesisStep* GetEndStep () {return m_End;}
+//	void RemoveStep (gcpRetrosynthesisStep *Step);
+
+private:
+	gcpRetrosynthesisStep *m_Start, *m_End;
 };
 
-#ifndef GCHEMPAINT_RETROSYNTHESIS_ARROW_H
-#define GCHEMPAINT_RETROSYNTHESIS_ARROW_H
-
-
-
 #endif	// GCHEMPAINT_RETROSYNTHESIS_ARROW_H
