@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -49,7 +49,7 @@ bool gcpElementTool::OnClicked()
 	if (m_pObject)
 	{
 		if (m_pObject->GetType() != AtomType) return false; 
-		if 	(((gcpAtom*)m_pObject)->GetTotalBondsNumber() > Element::GetMaxBonds(CurZ)) return false;
+		if 	(((gcpAtom*)m_pObject)->GetTotalBondsNumber() > (int) Element::GetMaxBonds(CurZ)) return false;
 		((gcpAtom*)m_pObject)->GetCoords(&m_x0, &m_y0);
 		m_x0 *= m_dZoomFactor;
 		m_y0 *= m_dZoomFactor;
