@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -48,7 +48,6 @@ gcpBondTool::~gcpBondTool ()
 
 bool gcpBondTool::OnClicked ()
 {
-	double x1, y1, x2, y2;
 	int i;
 	m_pAtom = NULL;
 	m_pItem = NULL;
@@ -535,7 +534,6 @@ gcpDownBondTool::~gcpDownBondTool()
 void gcpDownBondTool::Draw()
 {
 	double dx, dy, dx1, dy1, length;
-	GnomeCanvasGroup* group;
 	m_pItem = gnome_canvas_item_new(m_pGroup, gnome_canvas_group_ext_get_type(), NULL);
 	length = sqrt(square(m_x1 - m_x0) + square(m_y1 - m_y0));
 	if (length == 0.0) return;
@@ -634,7 +632,6 @@ gcpSquiggleBondTool::~gcpSquiggleBondTool()
 
 void gcpSquiggleBondTool::Draw()
 {
-	while(gtk_events_pending()) gtk_main_iteration();
 	GnomeCanvasPathDef *path_def;
 	path_def = gnome_canvas_path_def_new();
 	gnome_canvas_path_def_moveto(path_def, m_x0, m_y0);
