@@ -4,9 +4,9 @@
  * GChemPaint cycles plugin
  * cycletool.cc 
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -221,8 +221,8 @@ bool gcpCycleTool::OnClicked()
 						orientations.reserve(i);
 						pBond = (gcpBond*)pAtom->GetFirstBond(j);
 						orientations.push_back(pBond->GetAngle2DRad(pAtom));
-						int k;
-						while (pBond = (gcpBond*)pAtom->GetNextBond(j))
+						unsigned k;
+						while ((pBond = (gcpBond*)pAtom->GetNextBond(j)))
 						{
 							k = 0;
 							a0 = pBond->GetAngle2DRad(pAtom);
@@ -309,7 +309,7 @@ void gcpCycleTool::OnDrag()
 			x1 = (m_x - m_xn[0]) * (m_xn[3] - m_xn[1]) + (m_xn[1] - m_y) * (m_xn[2] - m_xn[0]);
 			if (m_nState & GDK_SHIFT_MASK)
 			{
-				if (m_Chain->GetLength() == m_size - 2) return;
+				if (m_Chain->GetLength() == (unsigned) m_size - 2) return;
 				gcpBond* pBond;
 				if (pObject)
 				{
@@ -527,25 +527,29 @@ void gcpCycleTool::OnDrag()
 
 void gcpCycleTool::OnRelease()
 {
-	if (!m_size) return;
-	double x1, y1, x2, y2;
-	if (m_Chain)
-	{
+	if (!m_size)
+		return;
+	if (m_Chain) {
 		delete m_Chain;
 		m_Chain = NULL;
 	}
-	if (m_pItem)
-	{
-		gtk_object_destroy(GTK_OBJECT(GNOME_CANVAS_ITEM(m_pItem)));
+	if (m_pItem) {
+		gtk_object_destroy (GTK_OBJECT (GNOME_CANVAS_ITEM (m_pItem)));
 		m_pItem = NULL;
 	}
-	else return;
-	if (!m_bAllowed) return;
-	m_pApp->ClearStatus();
+	else
+		return;
+	if (!m_bAllowed)
+		return;
+	m_pApp->ClearStatus ();
 	gcpAtom* pAtom[m_size];
 	gcpBond* pBond;
+	Object *pObject;
+	char const *Id;
 	GnomeCanvasItem* pItem;
-	gcpDocument* pDoc = m_pView->GetDoc();
+	gcpDocument *pDoc = m_pView->GetDoc ();
+	gcpOperation *pOp = NULL;
+	gcpMolecule *pMol = NULL;
 	int i;
 	for (i = 0; i < m_size; i++)
 	{
@@ -565,6 +569,21 @@ void gcpCycleTool::OnRelease()
 			{
 				pAtom[i] = (gcpAtom*)m_pObject;
 			}
+			if (pAtom[i]) {
+				if (pMol == NULL) {
+					pMol = reinterpret_cast<gcpMolecule *> (pAtom[i]->GetMolecule ());
+					pMol->Lock (true);
+				}
+				// if group not in ModifiedObjects, add it and save it
+				pObject = pAtom[i]->GetGroup ();
+				Id = pObject->GetId ();
+				if (ModifiedObjects.find (Id) == ModifiedObjects.end ()) {
+					if (!pOp)
+						pOp = pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
+					pOp->AddObject (pObject);
+					ModifiedObjects.insert (Id);
+				}
+			}
 		}
 		if (!pAtom[i])
 		{
@@ -587,6 +606,25 @@ void gcpCycleTool::OnRelease()
 		pBond = new gcpBond(pAtom[m_size - 1], pAtom[0], 1);
 		pDoc->AddBond(pBond);
 	}
+	pObject = pBond->GetGroup ();
+	if (pOp) {
+		ModifiedObjects.insert (pObject->GetId ());
+		set<string>::iterator it, end = ModifiedObjects.end();
+		for (it = ModifiedObjects.begin(); it != end; it++) {
+			pObject = pDoc->GetDescendant ((*it).c_str ());
+			if (pObject)
+				pOp->AddObject (pObject, 1);
+		}
+	} else {
+		pOp = pDoc->GetNewOperation (GCP_ADD_OPERATION);
+		pOp->AddObject (pObject);
+	}
+	pDoc->FinishOperation ();
+	if (pMol) {
+		pMol->Lock (false);
+		pMol->EmitSignal (OnChangedSignal);
+	}
+	ModifiedObjects.clear ();
 }
 
 void gcpCycleTool::OnChangeState()
