@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -30,11 +30,18 @@
 #include "lib/molecule.h"
 #include "selectiontool.h"
 #include "erasertool.h"
+#include "group.h"
 
 gcpSelectionPlugin plugin;
 
+static Object* CreateGroup ()
+{
+	return new gcpGroup ();
+}
+
 gcpSelectionPlugin::gcpSelectionPlugin(): gcpPlugin()
 {
+	GroupType = Object::AddType ("group", CreateGroup);
 }
 
 gcpSelectionPlugin::~gcpSelectionPlugin()
