@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2001-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -35,19 +35,19 @@
 #include <math.h>
 #include <stdexcept>
 
-static bool on_flip(GtkWidget *btn, gcpApplication* App)
+static void on_flip(GtkWidget *btn, gcpApplication* App)
 {
 	gcpSelectionTool *tool = (gcpSelectionTool*) App->GetTool ("Select");
 	tool->OnFlip (strcmp (gtk_widget_get_name (btn), "VertFlip"));
 }
 
-static bool on_rotate(GtkWidget *btn, gcpApplication* App)
+static void on_rotate(GtkWidget *btn, gcpApplication* App)
 {
 	gcpSelectionTool *tool = (gcpSelectionTool*) App->GetTool ("Select");
 	tool->Rotate (gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (btn)));
 }
 
-static bool on_merge(GtkWidget *btn, gcpApplication* App)
+static void on_merge(GtkWidget *btn, gcpApplication* App)
 {
 	gcpSelectionTool *tool = (gcpSelectionTool*) App->GetTool ("Select");
 	tool->Merge ();
@@ -362,7 +362,7 @@ static void on_group (gcpSelectionTool* tool)
 void gcpSelectionTool::Group ()
 {
 	gcpDocument *pDoc = m_pView->GetDoc ();
-	gcpGroupDlg *dlg = new gcpGroupDlg (pDoc, NULL);
+	new gcpGroupDlg (pDoc, NULL);
 }
 
 void gcpSelectionTool::CreateGroup ()
@@ -397,7 +397,6 @@ void gcpSelectionTool::CreateGroup ()
 bool gcpSelectionTool::OnRightButtonClicked (GtkUIManager *UIManager)
 {
 	// first destroy the GtkUIManager
-	GtkWidget *w;
 	if (m_pData->SelectedObjects.size () > 1) {
 		GtkActionGroup *group = gtk_action_group_new ("selection");
 		GtkAction *action = gtk_action_new ("group", _("Group and/or align objects"), NULL, NULL);
