@@ -2,9 +2,9 @@
  * GChemPaint templates plugin
  * gtkcombotoolitem.c
  *
- * Copyright (C) 2004
+ * Copyright (C) 2004-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -27,6 +27,7 @@
 #include <gtk/gtkcombobox.h>
 #include <gtk/gtkaction.h>
 #include <gtk/gtkcelllayout.h>
+#include <gtk/gtkcellrenderertext.h>
 
 static void
 gtk_tool_combo_class_init (GtkToolItemClass *tool_item_class)
