@@ -4,7 +4,7 @@
  * GChemPaint text plugin
  * fragmenttool.cc 
  *
- * Copyright (C) 2003-2004
+ * Copyright (C) 2003-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -53,10 +53,10 @@ static void on_get_data(GtkClipboard *clipboard, GtkSelectionData *selection_dat
 
 bool gcpFragmentTool::OnClicked()
 {
-	void *func;
-	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType() != FragmentType) || (m_Active != m_pData->Items[m_pObject]->item_list->data)))
-	{
-		if (!Unselect()) return false;
+	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType() != FragmentType) ||
+			(m_Active != g_object_get_data (G_OBJECT (m_pData->Items[m_pObject]), "fragment")))) {
+		if (!Unselect ())
+			return false;
 	}
 	if (!m_pObject)
 	{
@@ -219,25 +219,33 @@ bool gcpFragmentTool::OnEvent(GdkEvent* event)
 	return false;
 }
 
-bool gcpFragmentTool::CopySelection(GtkClipboard *clipboard)
+bool gcpFragmentTool::CopySelection (GtkClipboard *clipboard)
 {
-	if (!m_Active) return false;
-	GtkTextBuffer* buf = gnome_canvas_rich_text_ext_get_buffer(m_Active);
+	if (!m_Active)
+		return false;
+	GtkTextBuffer* buf = gnome_canvas_rich_text_ext_get_buffer (m_Active);
 	GtkTextIter start, end;
-	gtk_text_buffer_get_selection_bounds(buf, &start, &end);
-	if (gtk_text_iter_equal(&start, &end)) return false; //Nothing to copy
-	m_pData->Copy(clipboard); //To clean the xmlDoc
-	xmlDocPtr pDoc = m_pData->GetXmlDoc(clipboard);
-	if (!pDoc) return false;
-	pDoc->children = xmlNewDocNode(pDoc, NULL, (xmlChar*)"chemistry", NULL);
-	gcpFragment *fragment = (gcpFragment*)g_object_get_data(G_OBJECT(m_Active), "object");
-	xmlNodePtr node = fragment->SaveSelection(pDoc);
-	if (node) xmlAddChild(pDoc->children, node);
-	else return false;
-	gtk_clipboard_set_with_data(clipboard, targets, 2,
-				(GtkClipboardGetFunc)on_get_data,
-				(GtkClipboardClearFunc)on_clear_data, NULL);
-	gtk_clipboard_request_contents(clipboard, gdk_atom_intern ("TARGETS", FALSE),  (GtkClipboardReceivedFunc)on_receive_targets, NULL);
+	gtk_text_buffer_get_selection_bounds (buf, &start, &end);
+	if (gtk_text_iter_equal (&start, &end))
+		return false; //Nothing to copy
+	m_pData->Copy (clipboard); //To clean the xmlDoc
+	xmlDocPtr pDoc = m_pData->GetXmlDoc (clipboard);
+	if (!pDoc)
+		return false;
+	pDoc->children = xmlNewDocNode (pDoc, NULL, (xmlChar*) "chemistry", NULL);
+	gcpFragment *fragment = (gcpFragment*) g_object_get_data (G_OBJECT (m_Active), "object");
+	xmlNodePtr node = fragment->SaveSelection (pDoc);
+	if (node)
+		xmlAddChild (pDoc->children, node);
+	else
+		return false;
+	gtk_clipboard_set_with_data (clipboard, targets, 2,
+				(GtkClipboardGetFunc) on_get_data,
+				(GtkClipboardClearFunc) on_clear_data, NULL);
+	gtk_clipboard_request_contents (clipboard,
+			gdk_atom_intern ("TARGETS", FALSE),
+			(GtkClipboardReceivedFunc) on_receive_targets,
+			m_pApp);
 	return true;
 }
 
